@@ -1,7 +1,7 @@
 /**
  * Created by zhangyq on 2016/10/18.
  */
-
+var fs = require('fs');
 var path = require("path");
 var webpack = require("webpack");
 var webpackDevServer = require("webpack-dev-server");
@@ -9,6 +9,14 @@ var webpackCfg = require("./webpack.config.dev.js");
 webpackCfg.entry.app.unshift("webpack-dev-server/client?http://localhost:5389/", "webpack/hot/dev-server");
 //webpackCfg.entry.app.unshift("webpack-dev-server/client?http://localhost:5389/", "webpack/hot/only-dev-server");
 
+
+
+fs.exists("../dist/index.html",function(exists){
+  if(!exists){
+    fs.writeFileSync("../dist/index.html",fs.readFileSync("./index.html", 'utf-8'),'utf-8');
+  }
+});
+
 webpackCfg.plugins.push(new webpack.HotModuleReplacementPlugin());
 
 var compiler = webpack(webpackCfg), modulePath = webpackCfg.output.publicPath;
